@@ -20,13 +20,16 @@ class Printer:
     passed_count = 0
     
     def step(self, message):
-        print "{0}* {1}{2}" . format (bcolors.OKBLUE, message, bcolors.ENDC)
+        """
+        Print out a descriptive message explaining what we're doing
+        """
+        print ("{0}* {1}{2}" . format (bcolors.OKBLUE, message, bcolors.ENDC))
 
     def todo(self, message): 
-        print "{0}* **TODO:** {1}{2}" . format (bcolors.FAIL, message, bcolors.ENDC)
+        print ("{0}* **TODO:** {1}{2}" . format (bcolors.FAIL, message, bcolors.ENDC))
 
     def info(self, message):
-        print "{0}* **INFO:** {1}{2}" . format (bcolors.OKBLUE, message, bcolors.ENDC)     
+        print ("{0}* **INFO:** {1}{2}" . format (bcolors.OKBLUE, message, bcolors.ENDC))     
 
     def record_pass(self, message):
 
@@ -40,14 +43,14 @@ class Printer:
         self.print_fail(message)
 
     def scenario(self, message):
-        print " "
-        print "{0}##{1}{2}\n" . format (bcolors.OKGREEN, message, bcolors.ENDC)
+        print (" ")
+        print ("{0}##{1}{2}\n" . format (bcolors.OKGREEN, message, bcolors.ENDC))
         
     def print_pass(self, message):         
-        print "{0}* {1}{2}" . format (bcolors.OKGREEN, message, bcolors.ENDC)
+        print ("{0}* {1}{2}" . format (bcolors.OKGREEN, message, bcolors.ENDC))
 
     def print_fail(self, message): 
-        print "{0}* {1}{2}" . format (bcolors.FAIL, message, bcolors.ENDC)
+        print ("{0}* {1}{2}" . format (bcolors.FAIL, message, bcolors.ENDC))
         
 
     def print_summary(self):
@@ -57,10 +60,10 @@ class Printer:
             pass_percentage = float(self.passed_count) / assertion_count * 100
         else:
             pass_percentage = "n/a"
-        print "\n-"
-        print "* **Failed:** {0}" . format (self.failed_count)
-        print "* **Passed:** {0}" . format (self.passed_count)
-        print "* **Pass Rate:** {0} %" . format ( pass_percentage )
-        print "\n-"   
+        print ("\n-")
+        print ("* **Failed:** {0}" . format (self.failed_count))
+        print ("* **Passed:** {0}" . format (self.passed_count))
+        print ("* **Pass Rate:** {0} %" . format ( pass_percentage ))
+        print ("\n-")
 
     
